==> gambas3-debug-3.21.1-3-x86_64.pkg.tar.zst: usr/src/debug/gambas3/gambas-3.21.1/main/gbx/gbx_date.h <==
/***************************************************************************
  
  gbx_date.h
  
  (c) Benoît Minisini <benoit.minisini@gambas-basic.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  MA 02110-1301, USA.
  
***************************************************************************/

#ifndef __GBX_DATE_H
#define __GBX_DATE_H

#ifndef GBX_INFO

#include <sys/time.h>

#include "gbx_value.h"

typedef
  struct {
    int year;
    int month;
    int day;
    int hour;
    int min;
    int sec;
    int weekday;
    int msec;
    }
  DATE_SERIAL;

#ifndef __DATE_DECLARED
#define __DATE_DECLARED
typedef
  struct {
    int date;
    int time;
    }
  DATE;
#endif

#endif

#ifndef GBX_INFO

#define DATE_YEAR_MIN  -4801
#define DATE_YEAR_MAX   9999

#define DATE_NDAY_BC 1753350

#define DATE_UNIX_EPOCH 2472692

#define DATE_SERIAL_has_no_date(_date) ((_date)->year == 0)
#define DATE_SERIAL_has_no_time(_date) ((_date)->hour == 0 && (_date)->min == 0 && (_date)->sec == 0 && (_date)->msec == 0)

#define DATE_void_value(_value) ((_value)->type = T_DATE, (_value)->_date.time = (_value)->_date.date = 0)
	
void DATE_init(void);
void DATE_init_local(void);
int DATE_get_timezone(void);

DATE_SERIAL *DATE_split_local(VALUE *value, bool local);
#define DATE_split(_value) DATE_split_local(_value, TRUE)

bool DATE_make_local(DATE_SERIAL *date, VALUE *val, bool local);
#define DATE_make(_date, _value) DATE_make_local(_date, _value, TRUE)

void DATE_from_time(time_t time, int usec, VALUE *val);
void DATE_to_time(VALUE *val, time_t *time, int *usec);
void DATE_now(VALUE *val);

int DATE_to_string(char *buffer, VALUE *value);
bool DATE_from_string(const char *str, int len, VALUE *val, bool local);
int DATE_comp_value(VALUE *date1, VALUE *date2);
int DATE_comp(const DATE *date1, const DATE *date2);

double DATE_to_double(struct timeval *time, int from_start);
bool DATE_timer(double *result, int from_start);

void DATE_add(VALUE *date, int period, int val);
int DATE_diff(VALUE *date1, VALUE *date2, int period);

#endif

#endif

==> gambas3-debug-3.21.3-1-x86_64.pkg.tar.zst: usr/src/debug/gambas3/gambas-3.21.3/main/gbx/gbx_date.h <==
/***************************************************************************
  
  gbx_date.h
  
  (c) Benoît Minisini <benoit.minisini@gambas-basic.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  MA 02110-1301, USA.
  
***************************************************************************/

#ifndef __GBX_DATE_H
#define __GBX_DATE_H

#ifndef GBX_INFO

#include <sys/time.h>

#include "gbx_value.h"

typedef
  struct {
    int year;
    int month;
    int day;
    int hour;
    int min;
    int sec;
    int weekday;
    int msec;
    }
  DATE_SERIAL;

#ifndef __DATE_DECLARED
#define __DATE_DECLARED
typedef
  struct {
    int date;
    int time;
    }
  DATE;
#endif

#endif

#ifndef GBX_INFO

#define DATE_YEAR_MIN  -4801
#define DATE_YEAR_MAX   9999

#define DATE_NDAY_BC 1753350

#define DATE_UNIX_EPOCH 2472692

#define DATE_SERIAL_has_no_date(_date) ((_date)->year == 0)
#define DATE_SERIAL_has_no_time(_date) ((_date)->hour == 0 && (_date)->min == 0 && (_date)->sec == 0 && (_date)->msec == 0)

#define DATE_void_value(_value) ((_value)->type = T_DATE, (_value)->_date.time = (_value)->_date.date = 0)

void DATE_init(void);
void DATE_init_local(void);
int DATE_get_timezone(void);

DATE_SERIAL *DATE_split_local(VALUE *value, bool local);
#define DATE_split(_value) DATE_split_local(_value, TRUE)

bool DATE_make_local(DATE_SERIAL *date, VALUE *val, bool local);
#define DATE_make(_date, _value) DATE_make_local(_date, _value, TRUE)

void DATE_from_time(time_t time, int usec, VALUE *val);
void DATE_to_time(VALUE *val, time_t *time, int *usec);
void DATE_now(VALUE *val);

int DATE_to_string(char *buffer, VALUE *value);
bool DATE_from_string(const char *str, int len, VALUE *val, bool local);
int DATE_comp_value(VALUE *date1, VALUE *date2);
int DATE_comp(const DATE *date1, const DATE *date2);

double DATE_to_double(struct timeval *time, int from_start);
bool DATE_timer(double *result, bool from_start);

void DATE_add(VALUE *date, int period, int val);
int DATE_diff(VALUE *date1, VALUE *date2, int period);

#endif

#endif
